@@ -1,4 +1,4 @@
-from unogenerator import ODS, ODS_Standard
+from unogenerator import ODS, ODS_Standard, ODT_Standard
 
 with ODS() as doc:
     doc.createSheet("With")
@@ -8,4 +8,8 @@ with ODS() as doc:
 with ODS_Standard(2003) as doc:
     doc.createSheet("With")
     doc.addCellMergedWithStyle("A1:C3", "HOLA WITH")
-    doc.export_xlsx("borrar.xlsx")
\ No newline at end of file
+    doc.export_xlsx("borrar.xlsx")
+    
+with ODT_Standard() as doc:
+    doc.addParagraph("Hello world","Standard")
+    doc.export_pdf("borrar.pdf")
\ No newline at end of file
