@@ -2,15 +2,15 @@
 from colorama import Fore, Style
 from datetime import datetime, date
 from gettext import translation
-from logging import info, ERROR, WARNING, INFO, DEBUG, CRITICAL, basicConfig, error
+from logging import info, ERROR, WARNING, INFO, DEBUG, CRITICAL, basicConfig, error, debug
 from pkg_resources import resource_filename
 from psutil import process_iter
 from uno import createUnoStruct
 from unogenerator.reusing.listdict_functions import listdict_min
 from time import sleep
 
-__version__ = '0.24.0'
-__versiondatetime__=datetime(2022, 3, 24, 12, 44)
+__version__ = '0.25.0'
+__versiondatetime__=datetime(2022, 3, 31, 15, 0)
 __versiondate__=__versiondatetime__.date()
 
 try:
@@ -41,6 +41,13 @@ def datetime2uno( dt):
     r.Seconds=dt.second
     return r
 
+## Converts a com.sun.star.util.DateTime to datetime
+def uno2datetime(r):
+    try:
+        return datetime(r.Year, r.Month, r.Day, r.Hours, r.Minutes, r.Seconds)
+    except:
+        debug(_("There was a problem converting com.sun.star.util.DateTime to datetime."))
+
 def date2uno( dt):
     r=createUnoStruct("com.sun.star.util.Date")
     r.Year=dt.year
