@@ -15,8 +15,8 @@ from logging import warning, debug
 from pkg_resources import resource_filename
 from shutil import copyfile
 from tempfile import TemporaryDirectory
-from unogenerator.commons import Coord as C, ColorsNamed,  Range as R, datetime2uno, guess_object_style, row2index, column2index, datetime2localc1989, date2localc1989,  time2localc1989, next_port, get_from_process_numinstances_and_firstport,  is_formula
-from unogenerator.reusing.casts import lor_transposed
+from unogenerator.commons import Coord as C, ColorsNamed,  Range as R, datetime2uno, guess_object_style, row2index, column2index, datetime2localc1989, date2localc1989,  time2localc1989, next_port, get_from_process_numinstances_and_firstport,  is_formula, uno2datetime, __version__
+from unogenerator.reusing.casts import lor_transposed, f
 from unogenerator.reusing.currency import Currency
 from unogenerator.reusing.datetime_functions import string2dtnaive, string2date, string2time
 from unogenerator.reusing.percentage import Percentage
@@ -119,15 +119,34 @@ class ODF:
         self.language="es"
         self.country="ES"
 
-    def setMetadata(self, title="",  subject="", creator="", description="", keywords=[], creationdate=datetime.now()):
-        self.document.DocumentProperties.Author=creator
-        self.document.DocumentProperties.Generator=creator
-        self.document.DocumentProperties.Description=description
-        self.document.DocumentProperties.Subject=subject
-        self.document.DocumentProperties.Keywords=keywords
+    def getMetadata(self):
+        print("Author",  self.document.DocumentProperties.Author)
+        print(dir(self.document.DocumentProperties))
+        return {
+            "Author": self.document.DocumentProperties.Author, 
+            "Description": self.document.DocumentProperties.Description, 
+            "Subject": self.document.DocumentProperties.Subject, 
+            "Keywords": self.document.DocumentProperties.Keywords, 
+            "CreationDate": uno2datetime(self.document.DocumentProperties.CreationDate), 
+            "ModificationDate": uno2datetime(self.document.DocumentProperties.ModificationDate), 
+            "Title": self.document.DocumentProperties.Title, 
+        }
+        
+    ##Only sets a value when it's different of [] or ""
+    def setMetadata(self, title="",  subject="", author="", description="", keywords=[], creationdate=datetime.now()):
+        if author!="":
+            self.document.DocumentProperties.Author=author
+        self.document.DocumentProperties.Generator=f"UnoGenerator-{__version__}"
+        if description!="":
+            self.document.DocumentProperties.Description=description
+        if subject!="":
+            self.document.DocumentProperties.Subject=subject
+        if keywords!="":
+            self.document.DocumentProperties.Keywords=keywords
         self.document.DocumentProperties.CreationDate=datetime2uno(creationdate)
         self.document.DocumentProperties.ModificationDate=datetime2uno(creationdate)
-        self.document.DocumentProperties.Title=title
+        if title!="":
+            self.document.DocumentProperties.Title=title
 
     def deleteAll(self):
         self.executeDispatch(".uno:SelectAll")
@@ -219,9 +238,15 @@ class ODT(ODF):
             found=self.document.findNext(last,search)
         
         if found is not None:
-            found.setString("")
+            if found.HyperLinkTarget != "" or found.HyperLinkName != "" or found.HyperLinkURL != "":
+                url=found.HyperLinkURL
+                target=found.HyperLinkTarget
+                found.setString(replace)
+                found.HyperLinkURL=url
+                found.HyperLinkTarget=target
+            else:
+                found.setString(replace)
             self.cursor=found
-            found.Text.insertString(self.cursor, replace, False)
         else:
             if log is True:
                 warning(f"'{find}' was not found in the document'")
@@ -263,7 +288,31 @@ class ODT(ODF):
         else:
             warning(f"'{find}' was not found in the document'")
         
-    def addParagraph(self,  text,  style):
+    def addString(self, text, style=None, paragraphBreak=False):
+        if style is not None:
+            self.cursor.setPropertyValue("ParaStyleName", style)
+        self.document.Text.insertString(self.cursor, text, False)
+        if paragraphBreak is True:
+            self.document.Text.insertControlCharacter(self.cursor, ControlCharacter.PARAGRAPH_BREAK, False)
+        
+        
+        
+    def addStringHyperlink(self,  name,  url, paragraphBreak=False):
+
+        oVC = self.document.getCurrentController().getViewCursor()#		'Create View Cursor oVC at the end of document by default?
+        text=oVC.getText()
+        text.insertString(oVC, name,  True)
+        oVC.HyperLinkTarget=url
+        oVC.HyperLinkURL=url
+#        
+        oVC.goRight(len(name), False)
+        self.cursor.gotoRange(oVC,False)			#'Move Text Cursor to same location as oVC while selecting text in between (True)
+#        self.document.Text.insertString(self.cursor, " ",  False)
+
+        if paragraphBreak is True:
+            self.document.Text.insertControlCharacter(self.cursor, ControlCharacter.PARAGRAPH_BREAK, False)
+        
+    def addParagraph(self,  text,  style="Standard"):
         self.cursor.setPropertyValue("ParaStyleName", style)
         self.document.Text.insertString(self.cursor, text, False)
         self.document.Text.insertControlCharacter(self.cursor, ControlCharacter.PARAGRAPH_BREAK, False)
@@ -530,6 +579,11 @@ class ODS(ODF):
             columns=0
         else:
             columns=len(list_rows[0])
+            
+            
+        if rows==0 or columns==0:
+            debug(f(_("addListOfRowsWithStyle has {rows} rows and {columns } columns. Nothing to write. Ignoring...")))
+            return 
         
         if cellbycell is True:
             for i, row in enumerate(list_rows):
